@@ -309,7 +309,17 @@ def group_annotations(annotations, keyfunc):
     sorted_annotations = sorted(annotations, key=keyfunc)
     for k, g in groupby(sorted_annotations, keyfunc):
         sorted_group = sorted(g, key=left_longest_match, reverse=True)
-        groups[k] = RangeMap((a.start, a.end, a) for a in sorted_group)
+        for a in sorted_group:
+            addit = True
+            if a.start in groups[k] and a.end - 1 in groups[k]:
+                b = groups[k][a.start]
+                if a.start - b.start == 0 and a.end - b.end == 0:
+                    terms = set(b.terms)
+                    terms.update(set(a.terms))
+                    b.terms = list(terms)
+                    addit = False
+            if addit:
+                groups[k][a.start:a.end] = a
     return groups
 
 
