@@ -350,65 +350,6 @@ def test_SHERPA_1765():
     parameters = AFPEntitiesParameters(type=ConsolidationType.ref_first)
     docs = processor.process(docs, parameters)
     write_bug_result("SHERPA-1765", docs, parameters.type)
-    doc1 = docs[1]
-    lrem = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc1.annotations if
-                a.text == 'LREM')
-    with check:
-        assert lrem == IsPartialDict(label='AFPOrganization', text='LREM',
-                                     terms=Contains(
-                                         IsPartialDict(lexicon="organization",
-                                                       identifier='afporganization:190346'),
-                                         IsPartialDict(lexicon="wikidata",
-                                                       identifier='Q23731823')
-                                     ))
-
-    # doc6 = docs[6]
-    # lequipe = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc6.annotations if
-    #                a.text == "L'Equipe")
-    # with check:
-    #     assert lequipe == IsPartialDict(label='AFPOrganization', text="L'Equipe",
-    #                                  terms=Contains(
-    #                                      IsPartialDict(lexicon="organization",
-    #                                                    identifier='afporganization:190346'),
-    #                                      IsPartialDict(lexicon="wikidata",
-    #                                                    identifier='Q23731823')
-    #                                  ))
-
-    doc4 = docs[4]
-    cocacola = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc4.annotations if
-                    a.text == 'Coca-Cola')
-    with check:
-        assert cocacola == IsPartialDict(label='AFPOrganization', text='Coca-Cola',
-                                         terms=Contains(
-                                             IsPartialDict(lexicon="organization",
-                                                           identifier='afporganization:2571'),
-                                             IsPartialDict(lexicon="wikidata",
-                                                           identifier='Q3295867')
-                                         ))
-
-    doc2 = docs[2]
-    eelv = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc2.annotations if
-                a.text == "EELV")
-    with check:
-        assert eelv == IsPartialDict(label='AFPOrganization', text="EELV",
-                                     terms=Contains(
-                                         IsPartialDict(lexicon="organization",
-                                                       identifier='afporganization:4869'),
-                                         IsPartialDict(lexicon="wikidata",
-                                                       identifier='Q613786')
-                                     ))
-
-    doc3 = docs[3]
-    europe1 = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc3.annotations if
-                   a.text == "Europe 1")
-    with check:
-        assert europe1 == IsPartialDict(label='AFPOrganization', text="Europe 1",
-                                        terms=Contains(
-                                            IsPartialDict(lexicon="organization",
-                                                          identifier='afporganization:185731'),
-                                            IsPartialDict(lexicon="wikidata",
-                                                          identifier='Q314407')
-                                        ))
 
     doc0 = docs[0]
     reconquete = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc0.annotations if
@@ -420,8 +361,66 @@ def test_SHERPA_1765():
                                                              identifier='afporganization:201750')
                                            ))
 
+    doc1 = docs[1]
+    france2 = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc1.annotations if
+                   a.text == 'France 2')
+    with check:
+        assert france2 == IsPartialDict(label='AFPOrganization', text='France 2',
+                                        terms=Contains(
+                                            IsPartialDict(lexicon="organization",
+                                                          identifier='afporganization:5292')
+                                        ))
+
+    doc2 = docs[2]
+    lrem = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc2.annotations if
+                a.text == 'LREM')
+    with check:
+        assert lrem == IsPartialDict(label='AFPOrganization', text='LREM',
+                                     terms=Contains(
+                                         IsPartialDict(lexicon="organization",
+                                                       identifier='afporganization:190346'),
+                                         IsPartialDict(lexicon="wikidata",
+                                                       identifier='Q23731823')
+                                     ))
+
+    doc3 = docs[3]
+    eelv = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc3.annotations if
+                a.text == "EELV")
+    with check:
+        assert eelv == IsPartialDict(label='AFPOrganization', text="EELV",
+                                     terms=Contains(
+                                         IsPartialDict(lexicon="organization",
+                                                       identifier='afporganization:4869'),
+                                         IsPartialDict(lexicon="wikidata",
+                                                       identifier='Q613786')
+                                     ))
+
+    doc4 = docs[4]
+    europe1 = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc4.annotations if
+                   a.text == "Europe 1")
+    with check:
+        assert europe1 == IsPartialDict(label='AFPOrganization', text="Europe 1",
+                                        terms=Contains(
+                                            IsPartialDict(lexicon="organization",
+                                                          identifier='afporganization:185731'),
+                                            IsPartialDict(lexicon="wikidata",
+                                                          identifier='Q314407')
+                                        ))
+
     doc5 = docs[5]
-    ladygaga = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc5.annotations if
+    cocacola = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc5.annotations if
+                    a.text == 'Coca-Cola')
+    with check:
+        assert cocacola == IsPartialDict(label='AFPOrganization', text='Coca-Cola',
+                                         terms=Contains(
+                                             IsPartialDict(lexicon="organization",
+                                                           identifier='afporganization:2571'),
+                                             IsPartialDict(lexicon="wikidata",
+                                                           identifier='Q3295867')
+                                         ))
+
+    doc6 = docs[6]
+    ladygaga = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc6.annotations if
                     a.text == 'Lady Gaga')
     with check:
         assert ladygaga == IsPartialDict(label='AFPPerson', text='Lady Gaga',
@@ -432,6 +431,18 @@ def test_SHERPA_1765():
                                                            identifier='Q19848')
                                          ))
 
+    # doc7 = docs[7]
+    # lequipe = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc7.annotations if
+    #                a.text == "L'Equipe")
+    # with check:
+    #     assert lequipe == IsPartialDict(label='AFPOrganization', text="L'Equipe",
+    #                                  terms=Contains(
+    #                                      IsPartialDict(lexicon="organization",
+    #                                                    identifier='afporganization:190346'),
+    #                                      IsPartialDict(lexicon="wikidata",
+    #                                                    identifier='Q23731823')
+    #                                  ))
+
 
 # [AFP] No output with entities_fast for Arabic language
 def test_SHERPA_1766():
@@ -442,3 +453,27 @@ def test_SHERPA_1766():
     write_bug_result("SHERPA-1766", docs, parameters.type)
     doc0 = docs[0]
     assert len(doc0.annotations) > 0
+
+
+# [AFP] When an entity is present both in kb and kb_update with different identifiers,
+# the ambiguity is not preserved in the output
+def test_SHERPA_1773():
+    docs = get_bug_documents("SHERPA-1773")
+    processor = AFPEntitiesProcessor()
+    parameters = AFPEntitiesParameters(type=ConsolidationType.ref_first, remove_suspicious=False)
+    docs = processor.process(docs, parameters)
+    write_bug_result("SHERPA-1773", docs, parameters.type)
+    doc0 = docs[0]
+    assert len(doc0.annotations) > 0
+    borisbecker = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc0.annotations if
+                    a.text == 'Boris Becker')
+    with check:
+        assert borisbecker == IsPartialDict(label='AFPPerson', text='Boris Becker',
+                                         terms=Contains(
+                                             IsPartialDict(lexicon="person_update",
+                                                           identifier='afpperson:1976661'),
+                                             IsPartialDict(lexicon="person",
+                                                           identifier='afpperson:160236'),
+                                             IsPartialDict(lexicon="wikidata",
+                                                           identifier='Q76334')
+                                         ))
